@@ -18,10 +18,7 @@ pub struct CandidateRelayConfig {
 
 impl CandidateRelayConfig {
     /// Creates a new relay candidate.
-    pub async fn new_candidate_relay(
-        self,
-        agent_internal: Option<Arc<Mutex<AgentInternal>>>,
-    ) -> Result<CandidateBase, Error> {
+    pub async fn new_candidate_relay(self) -> Result<CandidateBase, Error> {
         let mut candidate_id = self.base_config.candidate_id;
         if candidate_id.is_empty() {
             candidate_id = generate_cand_id();
@@ -48,7 +45,6 @@ impl CandidateRelayConfig {
                 port: self.rel_port,
             }),
             conn: self.base_config.conn,
-            agent_internal,
             relay_client: self.relay_client.clone(),
             ..CandidateBase::default()
         };
